v6.6.0
======

Features
--------

- Require Python 3.8 or later.


Bugfixes
--------

- Repaired honeypot


v6.5.0
======

Features
--------

- Require Python 3.8 or later.


Bugfixes
--------

- Repaired honeypot
